@@ -1,19 +1,30 @@
-"""Author FredHappyface 2020...
+"""Author FredHappyface 2019-2022
 
 Uses pyppeteer to leverage a headless version of Chromium
 """
 from __future__ import annotations
 
 import asyncio
-from os import remove
+import  os
 
 from PIL import Image
+
+# 843427/	2021-02-02T11:07:25.313Z	-
+os.environ["PYPPETEER_CHROMIUM_REVISION"] = "843427"
+
 from pyppeteer import launch
 
 
 async def doGrabWebpage(url, resolution, evalJs):
 	"""Go to a URL, with a browser with a set resolution and run some js then take a screenshot."""
-	browser = await launch(options={"args": ["--no-sandbox", "--disable-web-security"]})
+	browser = await launch(
+		options={
+			"args": [
+				"--no-sandbox",
+				"--disable-web-security",
+			]
+		}
+	)
 	page = await browser.newPage()
 	await page.setViewport({"width": resolution[0], "height": resolution[1]})
 	await page.goto(url)
@@ -24,7 +35,7 @@ async def doGrabWebpage(url, resolution, evalJs):
 
 
 def grabWebpage(url: str, resolution: tuple[int, int] = (800, 600), evalJs=None):
-	"""Take a screenshot of a webpage...
+	"""Take a screenshot of a webpage
 
 	Args:
 		url (str): The url of the webpage in question
@@ -37,9 +48,9 @@ def grabWebpage(url: str, resolution: tuple[int, int] = (800, 600), evalJs=None)
 	asyncio.get_event_loop().run_until_complete(doGrabWebpage(url, resolution, evalJs))
 	image = Image.open("temp.png")
 	try:
-		remove("temp.png")
+		os.remove("temp.png")
 	except PermissionError:
 		print(
-			"WARNING: Unable to clean up, manually " + "remove temp.png from project root or ignore"
+			"WARNING: Unable to clean up, manually remove temp.png from project root or ignore"
 		)
 	return image
