@@ -36,9 +36,7 @@ def cropCentre(image: Image.Image, width: int | str, height: int | str) -> Image
 
 
 def expand(image: Image.Image, padding: int | str) -> Image.Image:
-	"""Uncrops the image with a padding...
-
-	padding can be one of the following:
+	"""Uncrops the image with a padding. padding can be one of the following:
 	pixel: int, percent: "val%", scale: "valx"
 
 	Args:
@@ -68,9 +66,7 @@ def expand(image: Image.Image, padding: int | str) -> Image.Image:
 
 
 def resize(image: Image.Image, width: int | str, height: int | str) -> Image.Image:
-	"""Resize an image with desired dimensions. This is most suitable for resizing non...
-
-	square images where a factor would not be sufficient.
+	"""Resize an image with desired dimensions. This is most suitable for resizing non square images where a factor would not be sufficient.
 	width, height can be one of the following:
 	pixel: int, percent: "val%", scale: "valx"
 
@@ -87,9 +83,7 @@ def resize(image: Image.Image, width: int | str, height: int | str) -> Image.Ima
 
 
 def resizeSquare(image: Image.Image, size: int | str) -> Image.Image:
-	"""Resize a square image. Or make a non square image square (will stretch if input...
-
-	image is non-square)
+	"""Resize a square image. Or make a non square image square (will stretch if input image is non-square)
 	size can be one of the following:
 	pixel: int, percent: "val%", scale: "valx"
 
